CollectionBloc class

Constructors

CollectionBloc({required ModelListBloc modelCollectionBloc, required ICollectionProvider pageListProvider, required LocalPageBloc filterStructureBloc, required EventBus eventBus})

Properties

eventBus → EventBus
final
filterStructureBloc → LocalPageBloc
final
globalSearchController → TextEditingController
final
globalSearchSilenced ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool
Whether the bloc is closed.
no setterinherited
modelCollectionBloc → ModelListBloc
final
pageListProvider → ICollectionProvider
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → CollectionState
The current state.
no setterinherited
stream → Stream<CollectionState>
The current stream of states.
no setterinherited

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
applyFilters({bool enforced = false}) → Future<void>
close() → Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
inherited
emit(CollectionState state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
loadCollection(String modelId) → Future<void>
? This method will be called when we first open a collection through the interface, or switch to a new collection from some other collection
makeFiltersBackup() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<CollectionState> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
paginate(int page) → Future<void>
restoreFiltersBackup() → Future<void>
sort(Field field, Order order) → Future<void>
toString() → String
A string representation of this object.
inherited
wipeQueryFilters() → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited