BaseDocumentState class

Available extensions
Annotations
  • @autoequal
  • @CopyWith.new(copyWithNull: true)
  • @JsonSerializable.new()

Constructors

BaseDocumentState({required Json data, required Json initialData, required bool isLoading, required bool isDeleting, required bool isSaving, required bool isError, required TextControllerMap controllerMap})
const
BaseDocumentState.empty()
factory
BaseDocumentState.fromJson(dynamic json)
factory

Properties

controllerMap → TextControllerMap
final
copyWith → _$BaseDocumentStateCWProxy

Available on BaseDocumentState, provided by the $BaseDocumentStateCopyWith extension

Returns a callable class that can be used as follows: instanceOfBaseDocumentState.copyWith(...) or like so:instanceOfBaseDocumentState.copyWith.fieldName(...).
no setter
data → Json
final
diff → Diff
no setter
hashCode → int
The hash code for this object.
no setterinherited
initialData → Json
final
isChanged → bool
no setter
isDeleting → bool
final
isError → bool
final
isLoading → bool
final
isSaving → bool
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited