DocumentBloc class

Inheritance
Implementers

Constructors

DocumentBloc({required ModelListBloc modelCollectionBloc, required IDocumentProvider documentProvider, required EventBus eventBus, required DraftService draftService})

Properties

documentId ↔ DocumentId?
getter/setter pairinherited
documentProvider → IDocumentProvider
final
draftKey → DocumentId?
no setterinherited
draftService → DraftService
finalinherited
eventBus → EventBus
final
hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool
Whether the bloc is closed.
no setterinherited
modelCollectionBloc → ModelListBloc
final
modelId ↔ DocumentId?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → DocumentState
The current state.
no setterinherited
stream → Stream<DocumentState>
The current stream of states.
no setterinherited

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
close() → Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
inherited
controllerFor(FieldId fieldId) → TextEditingController
inherited
create(Model model) → Future<void>
delete(Model model) → Future<void>
emit(DocumentState state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
fieldWasChanged(FieldId fieldId) → bool
inherited
hasThirdTableData(ModelId modelId) → bool
isPageExist(ModelId modelId, DocumentId documentId) → Future<bool>
loadPage(ModelId modelId, DocumentId documentId) → Future<void>
loadPageData({required DocumentId documentId, Model? model, ModelId? modelId}) → Future<Json>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<DocumentState> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
prepareForCreation(ModelId modelId) → Future<void>
reset(Model model) → Future<void>
save(Model model) → Future<void>
toString() → String
A string representation of this object.
inherited
updateThirdTableValue(ThirdTable thirdTable, Map<FieldId, List<FieldId>> thirdTableData) → void
updateValue(FieldId fieldId, dynamic fieldValue) → void
inherited
updateValues(Json json) → void
inherited
valueForKey(String key) → dynamic
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited