EditorState class

Available extensions
Annotations
  • @autoequal
  • @CopyWith.new()
  • @JsonSerializable.new()

Constructors

EditorState({required bool isLoading, required String xmlContent, required bool asyncMode, required ScreenContentType contentType, required bool canChangeContentType, required bool isSyncedWithFile, required MenuElement activeElement, required TagRenderer<Widget> activeTagRenderer})
const
EditorState.empty()
factory
EditorState.fromJson(dynamic json)
factory

Properties

activeElement → MenuElement
final
activeTagRenderer → TagRenderer<Widget>
final
asyncMode → bool
final
canChangeContentType → bool
final
contentType → ScreenContentType
final
copyWith → _$EditorStateCWProxy

Available on EditorState, provided by the $EditorStateCopyWith extension

Returns a callable class that can be used as follows: instanceOfEditorState.copyWith(...) or like so:instanceOfEditorState.copyWith.fieldName(...).
no setter
hashCode → int
The hash code for this object.
no setterinherited
isLoading → bool
final
isSyncedWithFile → bool
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
xmlContent → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited