EnumValue class

Available extensions
Annotations
  • @autoequal
  • @CopyWith.new()
  • @JsonSerializable.new()

Constructors

EnumValue({required String title, required Object value})
const
EnumValue.fromJson(dynamic json)
factory

Properties

copyWith → _$EnumValueCWProxy

Available on EnumValue, provided by the $EnumValueCopyWith extension

Returns a callable class that can be used as follows: instanceOfEnumValue.copyWith(...) or like so:instanceOfEnumValue.copyWith.fieldName(...).
no setter
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
title → String
final
value → Object
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
toString() → String
A string representation of this object.
inherited
typedValue<T>() → T

Operators

operator ==(Object other) → bool
The equality operator.
inherited