ExternalField class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

ExternalField({TitleFieldType? type, String? id, String? value})
factory
ExternalField.fromJson(dynamic json)
factory
ExternalField.id(String? id)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
isNotValid → bool
no setterinherited
isValid → bool
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strictValue → String
no setterinherited
type → TitleFieldType?
final
value → String?
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited