Field class abstract

Implementers
Available extensions
Annotations
  • @autoequal

Constructors

Field({required String id, required String name, bool showInList = false, bool isRequired = false, int sort = 0, bool realField = true, FormFieldValidator<Object>? validator, FieldType type = FieldType.field})
const

Properties

defaultValues → Set<String>
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
isBool → bool

Available on Field?, provided by the FieldTypesExtension extension

no setter
isDateTime → bool

Available on Field?, provided by the FieldTypesExtension extension

no setter
isEmpty → bool
no setter
isNumeric → bool

Available on Field?, provided by the FieldTypesExtension extension

no setter
isRequired → bool
final
isSingleLine → bool

Available on Field, provided by the IsSingleLineField extension

no setter
isString → bool

Available on Field?, provided by the FieldTypesExtension extension

no setter
name → String
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
realField → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showInList → bool
final
sort → int
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → FieldType
final
validator → FormFieldValidator<Object>?
final
virtualFields → List<Field>
no setter

Methods

description([BuildContext? context]) → FieldDescription
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
toModel() → Model
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited