HeaderField class

Inheritance
Available extensions
Annotations
  • @autoequal
  • @CopyWith.new()
  • @JsonSerializable.new()

Constructors

HeaderField({required String name, String? content, Color? contentColor, String? contentIcon, double? contentFontSize, bool useAsDivider = false, String? id, FieldType type = FieldType.headerField})
HeaderField.empty()
factory
HeaderField.fromJson(dynamic json)
factory

Properties

content → String
final
contentColor → Color?
final
contentFontSize → double?
final
contentIcon → String?
final
copyWith → _$HeaderFieldCWProxy

Available on HeaderField, provided by the $HeaderFieldCopyWith extension

Returns a callable class that can be used as follows: instanceOfHeaderField.copyWith(...) or like so:instanceOfHeaderField.copyWith.fieldName(...).
no setter
defaultValues → Set<String>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
isBool → bool

Available on Field?, provided by the FieldTypesExtension extension

no setter
isDateTime → bool

Available on Field?, provided by the FieldTypesExtension extension

no setter
isEmpty → bool
no setteroverride
isNumeric → bool

Available on Field?, provided by the FieldTypesExtension extension

no setter
isRequired → bool
finalinherited
isSingleLine → bool

Available on Field, provided by the IsSingleLineField extension

no setter
isString → bool

Available on Field?, provided by the FieldTypesExtension extension

no setter
name → String
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
realField → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showInList → bool
finalinherited
sort → int
finalinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → FieldType
finalinherited
useAsDivider → bool
final
validator → FormFieldValidator<Object>?
finalinherited
virtualFields → List<Field>
no setterinherited

Methods

description([BuildContext? context]) → FieldDescription
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
override
toModel() → Model
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited