ListFieldBloc class

Inheritance

Constructors

ListFieldBloc({required FieldChanged onEdit, required DraftService draftService, DynamicFieldItem? item, StructuredFieldItem? structuredItem})

Properties

documentId ↔ DocumentId?
getter/setter pairinherited
draftKey → DocumentId?
no setterinherited
draftService → DraftService
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool
Whether the bloc is closed.
no setterinherited
item → DynamicFieldItem?
final
modelId ↔ DocumentId?
getter/setter pairinherited
onEdit → FieldChanged
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → BaseDocumentState
The current state.
no setterinherited
stream → Stream<BaseDocumentState>
The current stream of states.
no setterinherited
structuredItem → StructuredFieldItem?
final

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
close() → Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
inherited
controllerFor(String fieldId) → TextEditingController
override
emit(BaseDocumentState state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
fieldWasChanged(FieldId fieldId) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<BaseDocumentState> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
toString() → String
A string representation of this object.
inherited
updateValue(String fieldId, dynamic fieldValue) → void
override
updateValues(Json json) → void
override
valueForKey(String key) → dynamic
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited