NumberType enum

Inheritance
Available extensions

Values

bit → const NumberType
float → const NumberType
double → const NumberType
tinyInt → const NumberType
smallInt → const NumberType
mediumInt → const NumberType
integer → const NumberType
bigInt → const NumberType

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isBigInt → bool
no setter
isBit → bool
no setter
isDouble → bool
no setter
isFloat → bool
no setter
isInteger → bool
no setter
isMediumInt → bool
no setter
isSmallInt → bool
no setter
isTinyInt → bool
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<NumberType>
A constant List of the values in this enum, in order of their declaration.