ScreenField class

Inheritance
Available extensions
Annotations
  • @autoequal
  • @CopyWith.new()
  • @JsonSerializable.new()

Constructors

ScreenField({required String name, required ScreenContentType screenContentType, String? binaryDataFieldId, String? id, bool showInList = false, bool isRequired = false, int sort = 0, FormFieldValidator<Object>? validator, FieldType type = FieldType.screenField})
ScreenField.empty()
factory
ScreenField.fromJson(dynamic json)
factory

Properties

binaryDataFieldId → String?
final
copyWith → _$ScreenFieldCWProxy

Available on ScreenField, provided by the $ScreenFieldCopyWith extension

Returns a callable class that can be used as follows: instanceOfScreenField.copyWith(...) or like so:instanceOfScreenField.copyWith.fieldName(...).
no setter
defaultValues → Set<String>
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
isBool → bool

Available on Field?, provided by the FieldTypesExtension extension

no setter
isDateTime → bool

Available on Field?, provided by the FieldTypesExtension extension

no setter
isEmpty → bool
no setteroverride
isNumeric → bool

Available on Field?, provided by the FieldTypesExtension extension

no setter
isRequired → bool
finalinherited
isSingleLine → bool

Available on Field, provided by the IsSingleLineField extension

no setter
isString → bool

Available on Field?, provided by the FieldTypesExtension extension

no setter
name → String
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
realField → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenContentType → ScreenContentType
final
showInList → bool
finalinherited
sort → int
finalinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → FieldType
finalinherited
validator → FormFieldValidator<Object>?
finalinherited
virtualFields → List<Field>
no setteroverride

Methods

description([BuildContext? context]) → FieldDescription
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
override
toModel() → Model
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited