StructuredFieldItem class

Available extensions
Annotations
  • @autoequal
  • @CopyWith.new()
  • @JsonSerializable.new()

Constructors

StructuredFieldItem({required List<DynamicFieldItem> items})
const
StructuredFieldItem.fromJson(dynamic json)
factory
StructuredFieldItem.fromQueryFilterFields({required DJson json, required List<Field> andOrStructure, required List<Field> valueStructure})
factory
StructuredFieldItem.fromValues(dynamic json, List<Field> fields)
factory

Properties

copyWith → _$StructuredFieldItemCWProxy

Available on StructuredFieldItem, provided by the $StructuredFieldItemCopyWith extension

Returns a callable class that can be used as follows: instanceOfStructuredFieldItem.copyWith(...) or like so:instanceOfStructuredFieldItem.copyWith.fieldName(...).
no setter
hashCode → int
The hash code for this object.
no setterinherited
items → List<DynamicFieldItem>
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
valueObject → List<Object?>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited