ThirdTable class

Available extensions
Annotations
  • @autoequal
  • @CopyWith.new()
  • @JsonSerializable.new()

Constructors

ThirdTable({required Model relationsEntity, required String parentEntityIdName, required String childEntityIdName})
const
ThirdTable.empty()
factory
ThirdTable.fromJson(dynamic json)
factory

Properties

childEntityIdName → String
final
copyWith → _$ThirdTableCWProxy

Available on ThirdTable, provided by the $ThirdTableCopyWith extension

Returns a callable class that can be used as follows: instanceOfThirdTable.copyWith(...) or like so:instanceOfThirdTable.copyWith.fieldName(...).
no setter
hashCode → int
The hash code for this object.
no setterinherited
parentEntityIdName → String
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
relationsEntity → Model
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Json
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited