ModelListState class

Available extensions
Annotations
  • @autoequal
  • @CopyWith.new()

Constructors

ModelListState({required List<Model> preloadedModels, required List<Model> collectionModels, required List<Model> soloModels, required List<Model> hiddenModels, required bool isError, required bool isLoading})
const
ModelListState.empty()
factory

Properties

allModels → List<Model>
no setter
collectionModels → List<Model>
final
copyWith → _$ModelListStateCWProxy

Available on ModelListState, provided by the $ModelListStateCopyWith extension

Returns a callable class that can be used as follows: instanceOfModelListState.copyWith(...) or like so:instanceOfModelListState.copyWith.fieldName(...).
no setter
hashCode → int
The hash code for this object.
no setterinherited
hiddenModels → List<Model>
final
isError → bool
final
isLoading → bool
final
preloadedModels → List<Model>
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
soloModels → List<Model>
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited