HumanException class

Implemented types

Constructors

HumanException({required String humanMessage, required String? originalMessage, required StackTrace? stackTrace, List<HumanException> errorsStack = const []})
const
HumanException.fromError({required String humanMessage, required Object? error})
factory

Properties

additionalInfo → String
no setter
errorsStack → List<HumanException>
final
errorsStackInfo → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasOriginalMessage → bool
no setter
hasStackTrace → bool
no setter
humanMessage → String
final
originalMessage → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
final
trace → Trace?
no setter

Methods

fullInfo([int? number]) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited