KitTextField class

Inheritance

Constructors

KitTextField({required TextEditingController controller, bool readOnly = false, List<TextInputFormatter> formatters = const [], String? placeholder, String? label, String? helper, ValueChanged<String>? onChanged, double size = kDefaultKitFieldSize, int? maxLines, double? maxHeight, VoidCallback? onPressed, bool isChanged = false, bool isRequired = false, FormFieldValidator<String?>? validator, FocusNode? focusNode, InputDecoration? decoration, IconData? suffixIcon, IconData? prefixIcon, Widget? suffix, Widget? prefix, Key? fieldKey, AutovalidateMode? autovalidateMode, Key? key})
const

Properties

autovalidateMode → AutovalidateMode?
final
controller → TextEditingController
final
decoration → InputDecoration?
final
fieldKey → Key?
final
focusNode → FocusNode?
final
formatters → List<TextInputFormatter>
final
hashCode → int
The hash code for this object.
no setterinherited
helper → String?
final
isChanged → bool
final
isRequired → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String?
final
maxHeight → double?
final
maxLines → int?
final
onChanged → ValueChanged<String>?
final
onPressed → VoidCallback?
final
placeholder → String?
final
prefix → Widget?
final
prefixIcon → IconData?
final
readOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
final
suffix → Widget?
final
suffixIcon → IconData?
final
validator → FormFieldValidator<String?>?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createInputDecoration({required BuildContext context, required bool isChanged, String? placeholder, String? label, double? maxHeight, String? helper}) → InputDecoration